EcpRouterProxy class

@author lzj

@since 2023/11/27 16:53

Constructors

EcpRouterProxy(GlobalKey<State<StatefulWidget>> navigatorKey)

Properties

hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

jumpTo<T>(String uri, {Map<String, dynamic>? arguments}) Future<T?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register<T>(Uri uri, String localUri, {RouterInterceptor<T>? interceptor, ArgsTransformer? transformer}) → void
registerUrl<T>(String uri, String localUri, {RouterInterceptor<T>? interceptor, ArgsTransformer? transformer}) → void
toString() String
A string representation of this object.
inherited
unregister(Uri uri) → void
unregisterUrl(String uri) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EcpRouterProxy
no setter

Static Methods

init(GlobalKey<State<StatefulWidget>> navigatorKey) EcpRouterProxy