MappingRouter class
Constructors
- MappingRouter(String uri, String localUri, {RouterInterceptor? interceptor, ArgsTransformer? argsTransformer})
Properties
- argsTransformer → ArgsTransformer?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interceptor → RouterInterceptor?
-
final
- localUri → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited